##  Adding or Editing Version Information
Whenever you are saving a diagram, as a best practice, add the description and version information to document the diagram's purpose and updates. Adding version info provides context about changes and provides clarity about the diagram's evolution, enabling better collaboration and reducing confusion for all the users involved.
If you are the creator or have write permission for the specific diagram, you can also add or edit version information later. To do so:
  1. In the version history panel, hover over the needed version and open the context menu by clicking on the 3 dot menu icon.
  2. Select Add Version info (or Edit Version info).
  3. Add or edit the needed information and click Save.
